@@ -43,6 +43,9 @@ Computer Aided Architectural Design
 @item CABS
 Carrier Access Billing System
 
+@item CABS
+Computer Aided Business Simulation
+
 @item CAC
 Computer Aided Crime
 
@@ -97,6 +100,9 @@ Center for the Application of Information Technology (org., USA)
 @item CAIT
 Central Academy of Information Technology (org., MITI)
 
+@item CAL
+Client Access License (Lotus, MS)
+
 @item CAL
 Computer Aided Logistics
 
@@ -178,6 +184,9 @@ Computer Aided aRchiving and Change Accounting System
 @item CARDS
 Central Archive for Reusable Defense Software (mil., USA)
 
+@item CARDVM
+Card Virtual Machine (Java, Sun), "CardVM"
+
 @item CARE
 Computer Assistance Resource Exchange
 
@@ -238,6 +247,9 @@ Computer-Assisted Tactical Information System (mil., USA)
 @item CATNIP
 Common ArchiTecture for Next generation Internet Protocol (IPNG, RFC 1707)
 
+@item CATS
+CodeWarrior Analysis Tools
+
 @item CAUCE
 Coalition Against Unsolicited Commercial Email (org., Internet, spam, UCE)
 
@@ -286,6 +298,9 @@ Compatibility Basic Input Output System (IBM, BIOS)
 @item CBMS
 Connectionless Broadband Data Service
 
+@item CBQ
+Class Based Queueing
+
 @item CBR
 Constant Bit Rate (ATM, VBR, ABR, UBR, QOS)
 
@@ -352,12 +367,18 @@ Centre Commun d'Etudes de Telediffusion et Telecommunications (org., France)
 @item CCF
 ??? (org.)
 
+@item CCF
+Capsulated Color Filter (NEC)
+
 @item CCF
 Central Computer Facility
 
 @item CCF
 Connection Control Function (IN)
 
+@item CCF
+Controller Configuration Facility
+
 @item CCFL
 Cold Cathode Fluorescent Lamp
 
@@ -436,12 +457,21 @@ China Coast Time [+0800] (TZ)
 @item CCTA
 Central Computer and Telecommunications Agency (org., UK)
 
+@item CCTLD
+Country Code Top Level DOMAIN (Internet, ICANN), "ccTLD"
+
 @item CCU
 Cache Control Unit (Wyse)
 
+@item CCU
+Customer Control Unit
+
 @item CCV
 C-bit Coding Violation [error event] (DS3/E3)
 
+@item CCW
+COM Callable Wrapper (MS, COM, Java)
+
 @item CD
 Carrier Detect (MODEM, RS-232)
 
@@ -460,6 +490,9 @@ Communications Decency Act (Internet, USA)
 @item CDA
 Compound Document Architecture (DEC)
 
+@item CDB
+Command Descriptor Block
+
 @item CDBS
 Connectionless Data Bearer Service
 
@@ -526,6 +559,9 @@ Compact Disk - Magneto Optical (CD), "CD-MO"
 @item CDMS
 Communication Driver Maintenance System (ISDN, HST)
 
+@item CDO
+Collaboration Data Objects (WSH, MS)
+
 @item CDPC
 Cellular Digital Packet Data
 
@@ -601,6 +637,9 @@ Cisco Educational ARCHive (Cisco, WWW)
 @item CEBIT
 welt CEntrum Buero Information Telekommunikation (fair), "CeBIT"
 
+@item CEDR
+[Microsoft Windows] Compact Edition Driver Repository (MS, Windows, CE)
+
 @item CEECEB
 Central and Eastern European Countries EDIFACT Board (org., EDIFACT), "CEEC/EB"
 
@@ -622,6 +661,9 @@ Comite Europeen de Normalisation (Europe, Brussels)
 @item CENELEC
 Comite Europeen de Normalisation ELECtrotechnique (org., CEN, Europe)
 
+@item CENTR
+Council of European National Top level DOMAIN Registries
+
 @item CEPAC
 CMOS-Ein-Platinen-Allzweck-Computer (IC, CMOS, C'T)
 
@@ -700,6 +742,9 @@ Call For Papers
 @item CFS
 Center for Standards (org., JIEO, DISA)
 
+@item CFS
+Cryptographic FileSystem (Linux, cryptography)
+
 @item CFV
 Call For Vote (Internet, Usenet), "CfV"
 
@@ -737,7 +782,7 @@ Copy Generation Management System (CD)
 Computer Graphics Reference Model (ISO, IEC, ISO/IEC 11072)
 
 @item CGVDI
-??? [Grafikbibliothek], "CG-VDI"
+Computer Graphic Virtual Device Interface, "CG-VDI"
 
 @item CHAID
 CHisquard Automatic Interaction Detector / Detection (SPSS)
@@ -766,6 +811,9 @@ Cylinder Head Sectors
 @item CHSM
 C Hardware Specific Module (NEST, MLID, Novell)
 
+@item CHV
+Card Holder Value [aka PIN] (ICC, PIN)
+
 @item CI
 Check In (RCS)
 
@@ -808,9 +856,6 @@ Configuration - Installation - Distribution (IBM)
 @item CIDF
 Common Intrusion Detection Framework (CIDF, IDS)
 
-@item CIDIR
-Classless Internet DOMAIN Routing [protocol] (???, CIDR)
-
 @item CIDR
 Classless Internet DOMAIN Routing [protocol] (RFC 1519)
 
@@ -829,6 +874,9 @@ Component Integration LABoratorieS (org.,, OpenDoc, Apple, IBM, Adobe, ...), CIL
 @item CIM
 Computer Integrated Manufacturing
 
+@item CIMOM
+CIM Object Model (CIM)
+
 @item CIO
 Cisco Information Online (Cisco, WWW)
 
@@ -904,6 +952,9 @@ Custom Local Area Signaling Service
 @item CLE
 Certified Lotus Engineer (Lotus)
 
+@item CLEC
+Competitive Local Exchange Carrier
+
 @item CLI
 Call Level Interface (SAQ, X/Open, Informix, ...)
 
@@ -1130,7 +1181,7 @@ Compressed News ReCeive Via UUCP
 Complimentary Network Service
 
 @item CNS
-Copuserve Network Services (CIS)
+Compuserve Network Services (CIS)
 
 @item CO
 Check Out (RCS)
@@ -1150,6 +1201,9 @@ COmmon Business Orientated Language
 @item COBRA
 ??? (org., Netherlands)
 
+@item COBRA
+COmmunication technology: Basic Research and Applications
+
 @item COCA
 Cost Of Cracking Adjustment (cryptography)
 
@@ -1258,6 +1312,9 @@ Common Object Request Broker Architecture (OMG)
 @item CORDIS
 COmmunity Research and Development Information Service (Europe)
 
+@item COS
+Card Operating System (OS, ICC)
+
 @item COS
 Class of Service
 
@@ -1412,7 +1469,7 @@ Card Random Access Memory (RAM, IC)
 Cable Repair Administrative System
 
 @item CRC
-Cyclic Redundancy Check
+Cyclic Redundancy Check[sum]
 
 @item CRCG
 [fraunhofer] Center for Research in Computer Graphics (org., USA)
@@ -1438,6 +1495,9 @@ Connection Related Function Virtual Path (UPC, UNI), "CRF(VP)"
 @item CRI
 Cray Research, Inc. (manufacturer)
 
+@item CRIMM
+Continuity Rambus Inline Memory Module (RIMM, IC, Rambus)
+
 @item CRIN
 Centre de Recherche en Informatique de Nancy (org., France)
 
@@ -1453,6 +1513,9 @@ Conversational Remote Job Entry (RJE)
 @item CRL
 Certificate Revocation List
 
+@item CRL
+Compile-time Reconfigurable Logic (RL)
+
 @item CRLF
 Carriage Return - Line Feed (ASCII, DOS)
 
@@ -1519,6 +1582,9 @@ Computer Sciences Corporation (provider)
 @item CSCC
 Concurrent SuperComputing Consortium (org.)
 
+@item CSCD
+Caldera Systems Curriculum Developers (Caldera)
+
 @item CSCSI
 Canadian Society for the Computational Studies of Intelligence (org., Canada, AI)
 
@@ -1546,6 +1612,9 @@ Client-Server Environment
 @item CSEIA
 [conference on] Computer Support for Environmental Impact Assessment (IFIP, conference)
 
+@item CSEL
+Cable SELect (EIDE, HD)
+
 @item CSELT
 Centro Studi E Laboratori Telecomunicazioni [s.p.a.] (org., Italy)
 
@@ -1595,7 +1664,7 @@ Carrier Sense Multiple Access
 Carrier Sense Multiple Access with Collision Avoidance, "CSMA/CA" 
 
 @item CSMACD
-Carrier Sense Multiple Access with Collision Detection (IEEE 802.3, ethernet), "CSMA/CD"
+Carrier Sense Multiple Access with Collision Detection (IEEE 802.3, ethernet, CSMA/CD), "CSMA/CD"
 
 @item CSMS
 C Specific Media Support (NEST, MLID, Novell)
@@ -1687,12 +1756,18 @@ Comma Separated Values
 @item CT
 [magazin fuer] Computer Technik, "c't" 
 
+@item CT
+Chipcard Terminal (ICC, CT)
+
 @item CT
 Chips & Technologies (manufacturer), "C&T"
 
 @item CTAN
 Comprehensive Tex Archive Network (TeX, FTP)
 
+@item CTAPI
+Chipcard Terminal Application Program Interface (ICC, CT, API), "CT-API"
+
 @item CTB
 Communication ToolBox (Apple)
 
@@ -1792,6 +1867,12 @@ Computer Virus Industry Association (org., USA)
 @item CVS
 Computer Vision Syndrome
 
+@item CVS
+Concurrent Versions System (Unix)
+
+@item CVSD
+Continuous Variable Delta Modulation (DFUE)
+
 @item CVSELP
 Codex Vector Sum Excited Linear Prediction [algorithm] (Motorola, VOFR)
 
