@@ -28,9 +28,15 @@ Fast Associated Control CHannel (GSM, DCCH)
 @item FACE
 Framed Access Command Environment (Unix, SVR4)
 
+@item FACS
+Firmware ACPI Control Structure (ACPI)
+
 @item FADU
 File Access Data Unit (FTAM)
 
+@item FAE
+Field Application Engineer
+
 @item FAG
 FernmeldeAnlagenGesetz
 
@@ -55,6 +61,9 @@ Family Application Programmer Interface (DOS, VDM, API)
 @item FAQ
 Frequently Asked Questions (slang, Usenet)
 
+@item FAR
+False Acception Rate
+
 @item FAR
 Fixed Alternative Routing (SNI)
 
@@ -142,6 +151,9 @@ Frequency Correction CHannel (GSM)
 @item FCCN
 Fundacao para a Computacao Cientifica Nacional (org., Portugal)
 
+@item FCD
+Floating Car Data
+
 @item FCFS
 First Come, First Served
 
@@ -160,6 +172,9 @@ Flow Control Operator Bits (DLSW)
 @item FCP
 [SCSI-3] Fibre Channel Protocol (SAM)
 
+@item FCPGA
+Flip Chip Pin Grid Array (CPU), "FC-PGA"
+
 @item FCPH
 Fibre Channel PHysical and signaling interface (SAM), "FC-PH"
 
@@ -209,11 +224,14 @@ Full Duplex EtherSwitch (Kalpana)
 File Definition Language
 
 @item FDM
-Frequency Division Multiplexing
+Frequency Division Multiplexing (FDM)
 
 @item FDMA
 Frequency Division Multiple Access (Mobile Systems)
 
+@item FDO
+Functional Device Object
+
 @item FDT
 Formal Description Technique
 
@@ -250,6 +268,9 @@ Forward Explicit Congestion Notification (ATM)
 @item FEIT
 Fujitsu Enhanced Imaging Technology (Fujitsu)
 
+@item FEK
+File Encryption Key (cryptography)
+
 @item FEM
 Finite Elemente Methode
 
@@ -320,7 +341,7 @@ Fixed Global Regular Expression Print (Unix, GREP)
 FreeHand Graphics Studio (Macromedia, DTP)
 
 @item FHSS
-Frequency Hopping Spread Spectrum (Wireless LAN)
+Frequency Hopping Spread Spectrum (WLAN)
 
 @item FIA
 Fiberoptic Industry Association (org.)
@@ -331,9 +352,15 @@ FInanzBUchhaltung
 @item FIC
 First International Computer [inc.] (manufacturer)
 
+@item FID
+File IDentifier (APDU)
+
 @item FID
 File Identifier Descriptor (UDF, CD-R)
 
+@item FIDO
+FIlter Device Object, "FiDO"
+
 @item FIF
 Fractal Interchange Format
 
@@ -373,6 +400,9 @@ Foundation for Intelligent Physical Agents (org., Agents)
 @item FIPS
 Federal Information Processing Standard (NIST, USA)
 
+@item FIR
+Fast IRDA (IRDA)
+
 @item FIRE
 Flexible Intelligent Routing Engine (3Com)
 
@@ -403,6 +433,9 @@ Functional Interpolating Transformation System
 @item FIU
 Fingerprint Identification Unit (Sony)
 
+@item FIZ
+FachInformationsZentrum karlsruhe Org., Germany
+
 @item FK
 Foundation Kit (NextStep, OpenStep, Apple, Rhapsody)
 
@@ -415,6 +448,9 @@ Fiber optic Link
 @item FLACC
 Full Level Algol Checkout Compiler
 
+@item FLAME
+FLexible API for Module-based Environments (RL, API)
+
 @item FLC
 Ferroelectric Liquid Crystal
 
@@ -422,7 +458,7 @@ Ferroelectric Liquid Crystal
 Four Letter Extended Acronym
 
 @item FLEXIP
-??? (Novell, Netware), "FLeX/IP"
+FLEXible Internet Protocol (Novell, Netware), "FLeX/IP"
 
 @item FLIM
 Faithful Library about Internet Message (EMACS, GNU)
@@ -439,6 +475,9 @@ Fast Link Pulse (ethernet, LAN, NLP)
 @item FM
 Frequenz-Modulation
 
+@item FMA
+Federated Management Architecture (Java)
+
 @item FMM
 Flash Memory Manager (Intel)
 
@@ -532,6 +571,9 @@ Field Of View (VRML)
 @item FOX
 Field Operational X.500
 
+@item FPA
+Fast Packet Adaption (FPS, FPR)
+
 @item FPA
 Floating Point Accelerator
 
@@ -571,6 +613,9 @@ Fast Page Mode [ram] (RAM, DRAM, IC)
 @item FPMDRAM
 Fast Page Mode DRAM (RAM, DRAM, IC), "FPM-DRAM"
 
+@item FPMPMI
+Flat Panel Monitor Physical Mounting Interface [standard] (LCD, VESA)
+
 @item FPNW
 File and Print service for NetWare (MS, Windows NT, DSMN)
 
@@ -586,6 +631,9 @@ Floating Point Processor
 @item FPP
 FORTRAN Pre-Processor (FORTRAN)
 
+@item FPR
+Fast Packet Relay (FPS, FPA)
+
 @item FPR
 Floating Point Register (FPU)
 
@@ -625,6 +673,9 @@ FRaMe Reject (HDLC, LAPB, SDLC)
 @item FROM
 Factory Read Only Memory (ROM)
 
+@item FRR
+False Rejection Rate
+
 @item FRR
 Functional Recovery Routine
 
@@ -652,9 +703,15 @@ Front Side Bus
 @item FSCK
 File System Consistency checK (Unix)
 
+@item FSD
+File System Driver
+
 @item FSF
 Free Software Foundation (org., GNU)
 
+@item FSIP
+Full Scale InPut (FSOP)
+
 @item FSK
 Frequency Shift Keying (DFUE)
 
@@ -664,9 +721,18 @@ Finite State Machine (TTCN, ...)
 @item FSMGDOS
 ??? Graphics Device Operating System (OS, Atari)
 
+@item FSO
+[scripting runtime library] File System Objects (MS, WSH)
+
+@item FSOP
+Full Scale OutPut (FSIP)
+
 @item FSP
 File Slurping Protocol
 
+@item FSRTL
+File System RunTime Library
+
 @item FSS
 Fast System Switch (Unix)
 
@@ -700,6 +766,12 @@ Federal Trade Commission (org., USA)
 @item FTN
 Fido Technology Network (FidoNet)
 
+@item FTNA
+File Transfer Access and Management
+
+@item FTNEA
+File Transfer NEtwork Architecure (SNI)
+
 @item FTOS
 File Transfer Open Systems
 
@@ -754,8 +826,10 @@ Flow Update Notification [message] (LFAP)
 @item FUNI
 Frame User Network Interface
 
-@item FUEV
-Fernmeldeanlagen-UEberwachungsVerordnung
+FUEV          Fernmeldeanlagen-UEberwachungsVerordnung
+
+@item FWH
+FirmWare Hub (BIOS, Intel)
 
 @item FWIW
 For What It's Worth (slang, Usenet, IRC)
