@@ -7,6 +7,9 @@
 @item H4P
 High Performance Parallel Processing Project (ICI)
 
+@item HACL
+Host Access Class Library (HOD, API)
+
 @item HACMP
 High Availability Clustered Multi Processing (IBM, RS/6000, Bull), "HA/CMP"
 
@@ -46,9 +49,15 @@ Host Bus Adapter (SCSI)
 @item HBCI
 HomeBanking Computer Interface (Internet, banking)
 
+@item HBT
+Hetero Bipolar Transistor (IBM, IC)
+
 @item HCI
 Human Computer Interaction (BCS, conference)
 
+@item HCL
+Hardware Compatibility List (MS, Windows)
+
 @item HCL
 Host Control Links
 
@@ -88,6 +97,9 @@ High Density Compact Disk (CD, Sony, Phillips)
 @item HDD
 Hard Disk Drive
 
+@item HDD
+Highly Doped Drain (IC, MOSFET)
+
 @item HDF
 Hierarchical Data Format (NCSA)
 
@@ -163,6 +175,9 @@ Handling the Electronic Representation of mixed text - image Office Documents ba
 @item HES
 Home Electronic System (SNI)
 
+@item HF
+Have Fun (slang, Usenet, IRC)
+
 @item HFC
 Hybrid Fiber Coax [network]
 
@@ -185,7 +200,7 @@ Hercules Graphics Adapter
 Hercules Graphics Card
 
 @item HHI
-Heinrich Hertz Institut (org., Deutschland)
+Heinrich Hertz Institut Org., Germany
 
 @item HI
 Hochschulverband Informationswissenschaften (org.)
@@ -217,6 +232,9 @@ Human Interface Graphical GENeration System (Uni Colorado)
 @item HINT
 Hierarchical INTegration [benchmark]
 
+@item HIPERLAN
+HIgh PErformance Radio Local Area Network (LAN, ETSI, EN 300 652)
+
 @item HIPPI
 HIgh Performance Parallel Interface
 
@@ -239,7 +257,7 @@ High Level Language Application Programming Interface (IBM, API)
 Higher Layer Protocol Identifier
 
 @item HLR
-Home Location Register (LR, GSM)
+Home Location Register (LR, GSM, GPRS)
 
 @item HLS
 Hue, Luminance, Saturation (color system, DTP)
@@ -280,18 +298,30 @@ Heinz Nixdorf Museumsforum (org., Paderborn, Germany)
 @item HNI
 Heinz Nixdorf Institut (org., ZIT)
 
+@item HOD
+Host On Demand (IBM, HOD)
+
 @item HOL
 Head Of Line
 
+@item HOMERF
+Home Radio Frequency (WLAN), "HomeRF"
+
 @item HOOPS
 Hierarchical Object Orientated Picture System (Ithaca, Autodesk, OOP)
 
+@item HOP
+Homecast Open Protocol (WLAN, Alation Systems)
+
 @item HP
 Hewlett Packard (manufacturer)
 
 @item HPBIDS
 Hewlett Packard Broadband Internet Delivery System (HP, Internet), "HP BIDS"
 
+@item HPC
+Handheld Personal Computer (PC), "H/PC"
+
 @item HPC
 High Performance Computing
 
@@ -328,6 +358,9 @@ Hewlett Packard Precision Architecture (HP, RISC)
 @item HPPCL
 Hewlett Packard Printer Control Language
 
+@item HPR
+High Performance Routing
+
 @item HPR
 High Priority Request (VUMA)
 
@@ -343,9 +376,15 @@ Hewlett-Packard Visual Engineering Environment (HP, GUI), "HP VEE"
 @item HPVUE
 Hewlett Packard - Visual User Environment (HP, GUI), "HP-VUE"
 
+@item HR
+High Rate (IEEE 802.11)
+
 @item HRC
 Hybrid Ring Control (FDDI)
 
+@item HRFWG
+Home Radio Frequency Working Group (WLAN, HOMERF)
+
 @item HS
 High Speed (MODEM)
 
@@ -358,6 +397,12 @@ Hue Saturation Brightness (DTP)
 @item HSC
 Hierarchical Storage Controller
 
+@item HSCDS
+High Speed Cable Data Services
+
+@item HSCSD
+High Speed Circuit Switched Data (GSM)
+
 @item HSFS
 High Sierra File System
 
@@ -391,6 +436,9 @@ Hierarchisches SpeicherManagement
 @item HSP
 [UUNet] HighSpeed Peering
 
+@item HSP
+Host Signal Processing (DFUE, WinModem)
+
 @item HSRP
 Hot Standby Router Protocol (Cisco, IOS)
 
@@ -427,6 +475,12 @@ Hope This Helps (slang)
 @item HTML
 HyperText Markup Language (Internet, WWW, SGML, RFC 1866/1942)
 
+@item HTPS
+High Temperature PolySilicon
+
+@item HTSI
+Host Transport Service Interface (ICC, CT-API)
+
 @item HTTP
 HyperText Transfer Protocol (WWW, RFC 2068)
 
@@ -451,6 +505,9 @@ Hue-Value-Chroma [model] (Tektronic, DTP)
 @item HVD
 High Voltage Differential [technology] (SCSI)
 
+@item HYCH
+Hope You Can Help (slang, Usenet, IRC)
+
 @item HYTEA
 HYperText Environment for Authoring (ESPRIT)
 
