@@ -10,12 +10,18 @@ Mandatory Access Control (MLS)
 @item MAC
 Media Access Control (ISO, OSI)
 
+@item MAC
+Membership Advisory Committee (ICANN)
+
 @item MAC
 Message Authentication Code (SSL, SRT, cryptography)
 
 @item MACH
 Multilayer ACtuator Head
 
+@item MACID
+Media Access Control IDentifier, "MAC-ID"
+
 @item MACOS
 MACintosh Operating System (Apple, OS), "MacOS"
 
@@ -40,12 +46,18 @@ Militaerischer AbschirmDienst (mil., org.)
 @item MADE
 Multimedia Application Development Environment (CWI)
 
+@item MADK
+Microsoft Activex Development Kit (ActiveX, MS)
+
 @item MAE
 Macintosh Application Environment (Apple, Sun, HPUX)
 
 @item MAINSAIL
 MAchine INdependent SAIL (SAIL)
 
+@item MAJC
+Microprocessor Architecture for Java Computing [pronounced 'magic'] (Sun, Java)
+
 @item MAJOUR
 Modular Application for JOURnals (EWS, SGML)
 
@@ -79,6 +91,9 @@ Manufacturing Automation Protocol/Technical Office Protocol, "MAP/TOP"
 @item MAR
 Microprogram Address Register
 
+@item MARC
+MAchine Readable Cataloging [record]
+
 @item MAS
 Multi Agent Systems (AI)
 
@@ -127,9 +142,15 @@ Mercedes-Benz AktienGesellschaft (Anwender)
 @item MBCMS
 Mercedes-Benz-Computer-Mikrofilm-System (MBAG), "MB-CMS"
 
+@item MBE
+Molecular Beam Epitaxy (IC; MOSFET)
+
 @item MBPS
 MegaBits Per Second
 
+@item MBR
+Master Boot Record
+
 @item MBS
 Maximum Burst Size
 
@@ -142,6 +163,9 @@ Micro Channel Architecture (IBM, PS/2)
 @item MCA
 Mission Critical Applications
 
+@item MCAD
+Mechanical CAD (AutoCAD, CAD)
+
 @item MCAV
 Modified Constant Angular Velocity
 
@@ -175,6 +199,9 @@ Meta Content Framework / Format (Apple, WWW)
 @item MCGA
 Multi Color Graphics Adapter (IBM, PS/2)
 
+@item MCH
+Memory Controller Hub [aka Northbridge] (Intel)
+
 @item MCI
 Measurement Layer Interface (UMA)
 
@@ -254,7 +281,7 @@ Mean Cell Transfer Delay (UNI, ATM)
 Management & Cascade Unit (Hub)
 
 @item MCU
-Micro Control Unit
+Micro Controller Unit (SIA)
 
 @item MCU
 Multipoint Control Unit
@@ -310,6 +337,9 @@ Multiple Document Interface (MS, Windows)
 @item MDI
 Multiplex Device Interface
 
+@item MDK
+MODEM Developers Kit (MODEM, MS)
+
 @item MDL
 Microstation Development Language (CAD)
 
@@ -325,6 +355,9 @@ Manufacturing Design System
 @item MDSE
 Message Delivery Service Element
 
+@item MDSP
+Mobile Device Sync Protocol (Lotus)
+
 @item MDT
 Mechanical DeskTop (SGI)
 
@@ -346,6 +379,9 @@ Mega Evil Grin (slang, Usenet, IRC)
 @item MEGA
 MessdatenErfassung und Graphische Auswertung
 
+@item MEI
+Matsushita Electronics Incorporated (manufacturer, Japan)
+
 @item MEL
 Maya Embedded Language
 
@@ -361,15 +397,24 @@ Manufacturing Execution System
 @item MES
 Menue-EntwicklungsSystem (Sinix, SNI)
 
+@item MESA
+MetaEmailSearchAgent (WWW, Internet)
+
 @item MESCH
 Multi-WAIS Engine for Searching Commercial Hosts (WAIS, WWW)
 
+@item MESFET
+MEtal Semiconductor Field Effect Transistor (IC, FET)
+
 @item MESH
 Macintosh Enhanced SCSI Hardware (Apple, SCSI)
 
 @item MESI
 Modified - Exclusive - Shared - Invalid (SMP)
 
+@item MESN
+Media Event Status Notification
+
 @item MESZ
 MittelEuropaeische SommerZeit [+0200] (TZ)
 
@@ -436,6 +481,9 @@ Message Format Service (IBM, IMS)
 @item MFS
 Mobile File Sync (IBM)
 
+@item MFT
+Master File Table (NTFS)
+
 @item MFV
 MehrFrequenzwahlVerfahren
 
@@ -466,15 +514,24 @@ Multimedia and Hypermedia information coding Expert Group (JTC1, ISO)
 @item MHP
 [columbia] Mobile Host Protocol
 
+@item MHP
+Multimedia Home Platform
+
 @item MHPCC
 Maui High Performance Computing Center (org., USA)
 
 @item MHS
 Message Handling System (GOSIP, X.400, Novell, SPX, IPX)
 
+@item MHTML
+Messaging HyperText Markup Language (HTML)
+
 @item MHTML
 MIME [e-mail encapsulation of aggregate documents, such as] HTML (MIME, HTML, RFC 2110)
 
+@item MI
+Management Interface
+
 @item MIAW
 Movie In A Window
 
@@ -485,7 +542,7 @@ Management Information Base (OSI, SNMP)
 Media Interface Connector (FDDI, PMD)
 
 @item MIC
-Memory in Cassette (Seagate, EEPROM)
+Memory in Cassette (Seagate, EEPROM, Streamer, AIT)
 
 @item MIC
 Message Integrity Check / Code
@@ -526,6 +583,9 @@ Matrox Imaging Library
 @item MILNET
 MILitary NETwork (USA, mil., network)
 
+@item MILOS
+Maschinelle Indizierung auf Linguistischer Grundlage fuer OPAC Systeme (OPAC)
+
 @item MILSTAR
 Military Strategic TActical Relay (mil., USA)
 
@@ -533,7 +593,7 @@ Military Strategic TActical Relay (mil., USA)
 Military STandarD (mil., USA), "MIL-STD"
 
 @item MIMD
-Multiple Instruction [stream], Multiple Data [stream]
+Multiple Instruction [stream], Multiple Data [stream] (CPU)
 
 @item MIME
 Multipurpose Internet Mail Extensions (RFC 2045/2046/2047/2048/2049, IETF)
@@ -562,6 +622,9 @@ Memory Input/Output (Motorola)
 @item MIO
 Modular Input/Output [architecture] (HP)
 
+@item MIP
+Multimission Interactive Picture
+
 @item MIPS
 Microprocessor without Interlocked Piped Stages
 
@@ -577,6 +640,9 @@ Micro-Instruction Register
 @item MIS
 Management Information System
 
+@item MISD
+Multiple Instruction [stream], Single Data [stream] (CPU)
+
 @item MISS
 Mecklenburg Internet Service System (ISP)
 
@@ -598,6 +664,9 @@ Modular Jack
 @item MKS
 Mortice Kern Systems (manufacturer)
 
+@item MKT
+Multifunktionelles KartenTerminal (CT, ICC)
+
 @item ML
 Mail List
 
@@ -635,7 +704,7 @@ Multi-Level Multi-Access (MAC)
 MultiLink Point-to-Point Protocol (PPP)
 
 @item MLR
-Multi-channel Linear Recording [technology] (Tandberg)
+Multi-channel Linear Recording [technology] (Tandberg, Streamer)
 
 @item MLS
 MultiLevel Secure [operating systems / platforms]
@@ -697,9 +766,15 @@ Multimode Fiberoptic cable
 @item MMFS
 Manufacturing Message Format Standard (MAP)
 
+@item MMHID
+MultiMedia Human Interface Device
+
 @item MMHS
 Military Message Handling System (mil., MHS)
 
+@item MMIO
+Memory Mapped I/O (I/O)
+
 @item MML
 Maker Markup Language (FrameMaker)
 
@@ -883,6 +958,9 @@ Multiprocessor Interconnect Bus
 @item MPIF
 Message Passing Interface Forum (manufacturer)
 
+@item MPL
+Mozilla Public License (Netscape)
+
 @item MPM
 Metra Potential Method
 
@@ -890,7 +968,7 @@ Metra Potential Method
 MultiMedia Presentation Manager/2 (OS/2, IBM), "MPM/2"
 
 @item MPML
-Main Profile @@@ Main Level (MPEG), "MP@@ML"
+Main Profile @@ Main Level (MPEG), "MP@@ML"
 
 @item MPOA
 Multi-Protocol Over ATM (ATM)
@@ -913,6 +991,9 @@ Microsoft Point-to-Point Compression (MS, RFC 2118)
 @item MPPD
 Multi Purpose Peripheral Device
 
+@item MPPE
+Microsoft Point to Point Encryption (MS, cryptography)
+
 @item MPPP
 Multilink Point-to-Point Protocol (PPP, RFC 1990, MP, Ascend)
 
@@ -956,7 +1037,7 @@ Multi Protocol Transport Services (IBM, MPTN)
 Multi Protocol Transport Services / 2 (IBM, OS/2), "MPTN/2" 
 
 @item MPU
-MicroProcessor Unit
+MicroProcessor Unit (SIA)
 
 @item MPU401
 MIDI Processing Unit 401 (Roland, MIDI), "MPU 401"
@@ -997,9 +1078,18 @@ Microsoft Realtime Compression Interface (MS)
 @item MRCS
 Multi-Rate Circuit Switching
 
+@item MRH
+Memory Repeater Hub (Intel)
+
 @item MRJ
 Macintosh / MacOS Runtime for Java (Java, Apple)
 
+@item MRJSDK
+Macintosh Runtime for Java Software Developer Kit (Apple, Java), "MRJ SDK"
+
+@item MRM
+Multi Resolution Meshes (Intel, 3D)
+
 @item MRNET
 Minnesota Regional NETwork (network, USA)
 
@@ -1061,7 +1151,7 @@ Most Significant Bit
 MicroSoft C
 
 @item MSC
-Mobile services Switching Center (PLMN, GSM)
+Mobile services Switching Center (PLMN, GSM, GPRS)
 
 @item MSCDEX
 MicroSoft Compact Disk EXtensions (CD)
@@ -1075,9 +1165,18 @@ Multiple Slots on Continuation Mechanism (DQDB)
 @item MSCP
 Mass Storage Control Protocol
 
+@item MSCS
+MicroSoft Cluster Server [Wolfpack] (MS)
+
 @item MSD
 Most Significant Digit
 
+@item MSDE
+MicroSoft Data Engine (MS, DB)
+
+@item MSDL
+MicroSoft Download Library (MS)
+
 @item MSDN
 Macintosh Software Distribution Network (FidoNet, Apple)
 
@@ -1093,6 +1192,9 @@ MicroSoft Disk Operating System (MS, OS)
 @item MSE
 MicroSoft Exchange server (MS)
 
+@item MSEN
+Media Status Event Notification
+
 @item MSFIS
 MicroSoft Fax Information Service (MS)
 
@@ -1106,7 +1208,7 @@ Medium Scale Integration
 Micro-Star International (manufacturer, Taiwan)
 
 @item MSIE
-MicroSoft Internet Explorer (MS, WWW)
+MicroSoft Internet Explorer (MS, WWW, MSIE)
 
 @item MSISDN
 Mobile Station ISDN Number (PLMN, GSM), "MS-ISDN"
@@ -1126,6 +1228,9 @@ Mirrored Server Link
 @item MSM
 Media Support Module (ODI)
 
+@item MSMQ
+MicroSoft Message Queue [server] (MS)
+
 @item MSN
 Microsoft Support Network (Internet, MS)
 
@@ -1237,6 +1342,9 @@ Microsoft Tape Format (MS)
 @item MTF
 Modulation Transfer Function
 
+@item MTH
+Memory Translator Hub (Intel)
+
 @item MTI
 MIPS Technologies Inc. (manufacturer, SGI)
 
@@ -1249,6 +1357,9 @@ Memory Type Range Register (CPU, Pentium Pro)
 @item MTS
 Message Transfer System (MHS)
 
+@item MTS
+Microsoft Transaction Server (MS, DB, WSH, COM)
+
 @item MTTF
 Mean Time To Failure
 
@@ -1318,8 +1429,7 @@ Master Upper Tester (ISO 9646-3, TTCN)
 @item MUTOS
 MultiUser-/multitasking Operating System (GDR, OS)
 
-@item MUEW
-eW MonopolUEbertragungsWeg, "MueW"
+MUEW          eW MonopolUEbertragungsWeg, "MueW"
 
 @item MUX
 MUltipleXer
