@@ -35,7 +35,7 @@ Rate Adaptive Digital Subscriber Line (ADSL)
 Remote Alarm Indication (DS3/E3)
 
 @item RAID
-Redundant Arrays of Independent Disks
+Redundant Array of Independent / Inexpensive Disks (HDD, RAID)
 
 @item RAIR
 Random Access Information Retrieval
@@ -118,6 +118,9 @@ Remote Bridge Management Software
 @item RBOC
 Regional Bell Operating Company (USA)
 
+@item RC
+Reconfigurable Computer / Computing (RL)
+
 @item RC
 Region Co-ordinator (FidoNet)
 
@@ -134,7 +137,7 @@ Routing Control
 Ron's Code 2/4 (cryptography), "RC2/4"
 
 @item RC5
-Rivest Cipher 5 ??? (RFC 2040, cryptography)
+Rivest Cipher 5 (RFC 2040, cryptography)
 
 @item RCAS
 Reserve Component Automation System
@@ -280,11 +283,14 @@ Remote Data Objects (DB)
 @item RDP
 Reliable Datagram Protocol
 
+@item RDP
+Remote Desktop Protocol (MS)
+
 @item RDR
 Request Data with Reply (Feldbus)
 
 @item RDRAM
-Rambus Dynamic Random Access Memory (RAM, IC)
+Rambus Dynamic Random Access Memory (RAM, IC, Rambus)
 
 @item RDRN
 Rapidly Deployable Radio Networks (USA, Uni Kansas)
@@ -358,6 +364,9 @@ Radio Frequency (Mobile Systems)
 @item RFA
 Request for Assistance (Internet)
 
+@item RFB
+Remote FrameBuffer [protocol]
+
 @item RFC
 Remote Function Call (SAP, CPIC)
 
@@ -382,6 +391,12 @@ Radio Frequency Interference
 @item RFI
 Request For Information (Internet)
 
+@item RFIC
+Radio Frequency Integrated Circuit (IC)
+
+@item RFID
+Radio Frequency IDentification (ANSI, NCITS)
+
 @item RFMS
 Remote File Management System
 
@@ -427,9 +442,15 @@ Routing Information
 @item RIACS
 Research Institute for Advanced Computer Science (org.)
 
+@item RID
+Relative IDentifier
+
 @item RIDE
 Research Issues in Data Engineering (IEEE-CS)
 
+@item RIE
+Reactive Ion Etching (IC)
+
 @item RIF
 Routing Information Field (Token Ring)
 
@@ -451,8 +472,11 @@ Remote Installation and Maintenance
 @item RIME
 Relaynet International Message Exchange
 
+@item RIMM
+Rambus Inline Memory Module (Rambus, IC)
+
 @item RIO
-Redistributed Internet Objects (S3, VRML)
+Redistributed Internet Objects (S3, VRML, Internet)
 
 @item RIP
 Raster Image Processor (DTP)
@@ -508,6 +532,12 @@ Remote Job Processing
 @item RKRM
 ROM Kernel Reference Manual (Amiga, Commodore)
 
+@item RL
+Reconfigurable Logic (RL)
+
+@item RLC
+Radio Link Control (GPRS)
+
 @item RLE
 Run-Length Encoded
 
@@ -592,6 +622,9 @@ Remote Network Access
 @item RND
 RAD Network Devices (RAD, manufacturer)
 
+@item RNI
+Raw Native Interface (MS, Java)
+
 @item RNOC
 Regional Network Operations Center
 
@@ -607,6 +640,9 @@ Read-Only (I/O)
 @item ROAMS
 Reusable Object Access and Management System
 
+@item ROC
+RAID On a Chip (RAID)
+
 @item ROD
 Rewritable Optical Disk (OD)
 
@@ -643,6 +679,9 @@ Rolling On The Floor Laughing (slang, Usenet, IRC)
 @item ROTFLBTC
 Rolling On The Floor Laughing and Biting The Carpet (slang, Usenet, IRC)
 
+@item ROTFLMAO
+Rolling On The Floor Laughing My Ass Off (slang, Usenet, IRC)
+
 @item RP
 Relay Party (IRC)
 
@@ -652,6 +691,9 @@ Remote Phrase Authentication
 @item RPC
 Remote Procedure Call (Sun, Xerox, OSF, ECMA, RFC 1831)
 
+@item RPC2
+Region code Playback Control phase 2 (DVD), "RPC-2"
+
 @item RPCL
 Remote Procedure Call Language (ONC, Sun)
 
@@ -697,6 +739,9 @@ Relational Query By Example (DB, QBE)
 @item RR
 Radio Resource management (MM, CM, GSM)
 
+@item RRAS
+Routing and Remote Access Service (MS, Windows NT)
+
 @item RRCM
 Reservation Request Control Mechanism (DQDB)
 
@@ -728,7 +773,7 @@ Reference System Architecture
 Reusable Software Assets
 
 @item RSA
-Rivest, Shamir und Adleman (cryptography, RSA)
+Rivest, Shamir and Adleman (cryptography, RSA)
 
 @item RSAC
 Recreational Software Advisory Council (org.)
@@ -775,9 +820,15 @@ Remote Switching Module
 @item RSN
 Real Soon Now (slang)
 
+@item RSP
+Reality Signal Processor (Nintendo)
+
 @item RSPC
 Reed Solomon Product Code (SDD), "RS-PC"
 
+@item RSSCP
+Remote System Services Control Point (SSCP)
+
 @item RSTS
 Resource Sharing Time Sharing (DEC)
 
@@ -793,6 +844,9 @@ Remote Switching Unit
 @item RSVP
 Resource reSerVation Protocol (IP)
 
+@item RSX
+Realistic Sound eXperience (Intel, audio)
+
 @item RSX11D
 Resource Sharing eXecutive - 11D (DEC), "RSX-11D"
 
@@ -814,6 +868,9 @@ Research and Technology, "R&T"
 @item RT
 Routing Type
 
+@item RTA
+Rapid Thermal Annealling (IC, MOSFET)
+
 @item RTA
 Real-Time Accelerator
 
@@ -841,6 +898,9 @@ Real Time Control Unit
 @item RTD
 Real Time Display
 
+@item RTDAT
+RealTime Deformation And Tessellation [engine] (3D, Shiny), "RT-DAT"
+
 @item RTDHS
 Real Time Data Handling System
 
@@ -964,6 +1024,9 @@ Read/Write (I/O), "R/W"
 @item RWCP
 Real World Computing Partnership (org., Japan)
 
+@item RWS
+Remote WinSock (Windows, TCP/IP)
+
 @item RZ
 RechenZentrum
 
